cli

package
v0.0.0-...-fad11a6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 11, 2025 License: MIT Imports: 16 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Run

func Run(env Environment) int

Types

type BackfillCmd

type BackfillCmd struct {
	AccountID  string `required help:"the account id that this backfill should take place in."`
	CampaignID string `required help:"the campaign id that this backfill should take place in."`
}

func (*BackfillCmd) Run

func (cmd *BackfillCmd) Run(env *Environment, client donatelyhttp.Client, adjustmentStore donately.AdjustmentStore) error

type CLI

type CLI struct {
	Backfill BackfillCmd `cmd help:"Backfills Donately donors based on a given account_id and csv file of donor data."`
	Serve    ServeCmd    `cmd help:"Serves our campaign progress service/ui for visualizing how brothers have progressed on their pledges."`
}

type Environment

type Environment struct {
	Stderr io.Writer
	Stdout io.Writer
	Stdin  io.Reader
	Files  embed.FS
	UI     embed.FS
}

Environment provides an abstraction around the execution environment

type ServeCmd

type ServeCmd struct {
	AccountID  string `required help:"the account id that this service should leverage."`
	CampaignID string `required help:"the campaign id that this service should leverage"`
}

func (*ServeCmd) Run

func (cmd *ServeCmd) Run(env *Environment, client donatelyhttp.Client, adjustmentStore donately.AdjustmentStore) error

Jump to